pub fn get_next_pending_signal(abi: &LinuxRiscv64Abi) -> Option<LinuxSignal>Expand description
Check if task has pending signals and return the next one to handle
pub fn get_next_pending_signal(abi: &LinuxRiscv64Abi) -> Option<LinuxSignal>Check if task has pending signals and return the next one to handle