process_pending_signals_with_state

Function process_pending_signals_with_state 

pub fn process_pending_signals_with_state(
    signal_state: &mut SignalState,
    trapframe: &mut Trapframe,
) -> bool
Process pending signals for a task with explicit signal state Returns true if a signal was handled and execution should be interrupted