sys_tkill

Function sys_tkill 

pub fn sys_tkill(abi: &mut LinuxRiscv64Abi, trapframe: &mut Trapframe) -> usize
Linux sys_tkill - Send a signal to a specific thread

tkill() sends a signal to a specific thread within the same thread group. This is a simplified implementation that mainly prevents crashes.

Arguments:

  • abi: LinuxRiscv64Abi context
  • trapframe: Trapframe containing syscall arguments
    • arg0: tid (thread ID)
    • arg1: sig (signal number)

Returns:

  • 0 on success
  • usize::MAX (Linux -1) on error